@@ -14,44 +14,44 @@ from napoleontoolbox.signal import signal_utility
 import json
 
 
-def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True):
-    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
-    print('average hourly turn over')
-    print(data['turn_over'].sum() / len(data))
-    data['close_return'] = data['close'].pct_change()
-    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
-    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
-    if transaction_cost :
-        data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
-    else :
-        data['perf_return'] = data['non_adjusted_perf_return']
-    data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
-    return data
-
-def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
-    signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
-    signal_df = signal_df.to_frame()
-    signal_df.columns = ['signal_gen']
-    signal_df['signal'] = signal_df['signal_gen'].shift()
-    if trigger:
-        signal_df['signal'] =  signal_df['signal'].fillna(method='ffill')
-
-    signal_df = signal_df.fillna(0.)
-    rolled_df = pd.merge(rolled_df, signal_df, how='left', left_index=True, right_index= True)
-    rolled_df = rolled_df.iloc[skipping_size:]
-    return rolled_df
-
-def roll(df, w):
-    v = df.values
-    d0, d1 = v.shape
-    s0, s1 = v.strides
-    restricted_length = d0 - (w - 1)
-    a = stride(v, (restricted_length, w, d1), (s0, s0, s1))
-    rolled_df = pd.concat({
-        row: pd.DataFrame(values, columns=df.columns)
-        for row, values in zip(df.index[-restricted_length:], a)
-    })
-    return rolled_df.groupby(level=0)
+# def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True):
+#     data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
+#     print('average hourly turn over')
+#     print(data['turn_over'].sum() / len(data))
+#     data['close_return'] = data['close'].pct_change()
+#     data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+#     data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
+#     if transaction_cost :
+#         data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
+#     else :
+#         data['perf_return'] = data['non_adjusted_perf_return']
+#     data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
+#     return data
+#
+# def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
+#     signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
+#     signal_df = signal_df.to_frame()
+#     signal_df.columns = ['signal_gen']
+#     signal_df['signal'] = signal_df['signal_gen'].shift()
+#     if trigger:
+#         signal_df['signal'] =  signal_df['signal'].fillna(method='ffill')
+#
+#     signal_df = signal_df.fillna(0.)
+#     rolled_df = pd.merge(rolled_df, signal_df, how='left', left_index=True, right_index= True)
+#     rolled_df = rolled_df.iloc[skipping_size:]
+#     return rolled_df
+#
+# def roll(df, w):
+#     v = df.values
+#     d0, d1 = v.shape
+#     s0, s1 = v.strides
+#     restricted_length = d0 - (w - 1)
+#     a = stride(v, (restricted_length, w, d1), (s0, s0, s1))
+#     rolled_df = pd.concat({
+#         row: pd.DataFrame(values, columns=df.columns)
+#         for row, values in zip(df.index[-restricted_length:], a)
+#     })
+#     return rolled_df.groupby(level=0)
 
 
 
@@ -73,14 +73,15 @@ class AbstractRunner(ABC):
                                                                  list_pkl_file_name=self.list_pkl_file_name)
 
     @abstractmethod
-    def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs):
+    def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs, normalization):
         pass
 
 
 class EnsemblingSignalRunner(AbstractRunner):
-    def runTrial(self, saver, seed, trigger, transaction_costs):
+    def runTrial(self, saver, seed, trigger, transaction_costs, normalization):
         cumulated_signals = None
         counter = 0
+        print('Number of signals to aggregate '+str(len(self.signals_list)))
         for me_signal in self.signals_list:
             # we have to reload the file each time
             hourly_df = pd.read_pickle(self.local_root_directory + self.hourly_pkl_file_name)
@@ -106,9 +107,9 @@ class EnsemblingSignalRunner(AbstractRunner):
                     raise Exception('The skipping size must be greater than the lookback window')
                 # kwargs = {**generics, **idios}
                 signal_generation_method_to_call = getattr(signal_generator, signal_type)
-                hourly_df = roll_wrapper(hourly_df, lookback_window, self.skipping_size,
+                hourly_df = signal_utility.roll_wrapper(hourly_df, lookback_window, self.skipping_size,
                                           lambda x: signal_generation_method_to_call(data=x, **params), trigger)
-                hourly_df = reconstitute_signal_perf(data = hourly_df, transaction_cost = False)
+                hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs, normalization = normalization)
             if cumulated_signals is None:
                 if self.add_turn_over:
                     cumulated_signals = hourly_df[['close','signal','turn_over']]
@@ -120,7 +121,7 @@ class EnsemblingSignalRunner(AbstractRunner):
                 cumulated_signals['signal'+str(counter)]=hourly_df['signal']
                 if self.add_turn_over:
                     cumulated_signals['turn_over'+str(counter)]=hourly_df['turn_over']
-            hourly_df = hourly_df.drop(columns = ['signal','turn_over','reconstituted_perf','non_adjusted_perf_return','perf_return'])
+            #hourly_df = hourly_df.drop(columns = ['signal','turn_over','reconstituted_perf','non_adjusted_perf_return','perf_return'])
             counter = counter + 1
         print('saving to '+self.aggregated_pkl_file_name)
         cumulated_signals.to_pickle(self.local_root_directory+self.aggregated_pkl_file_name)
