@@ -7,37 +7,12 @@ import pandas as pd
 
 from napoleontoolbox.file_saver import dropbox_file_saver
 from napoleontoolbox.utility import metrics
-from numpy.lib.stride_tricks import as_strided as stride
+
 from napoleontoolbox.signal import signal_generator
 from napoleontoolbox.signal import signal_utility
 
 import json
 
-def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
-    signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
-    signal_df = signal_df.to_frame()
-    signal_df.columns = ['signal_gen']
-    signal_df['signal'] = signal_df['signal_gen'].shift()
-    if trigger:
-        signal_df['signal'] =  signal_df['signal'].fillna(method='ffill')
-
-    signal_df = signal_df.fillna(0.)
-    rolled_df = pd.merge(rolled_df, signal_df, how='left', left_index=True, right_index= True)
-    rolled_df = rolled_df.iloc[skipping_size:]
-    return rolled_df
-
-def roll(df, w):
-    v = df.values
-    d0, d1 = v.shape
-    s0, s1 = v.strides
-    restricted_length = d0 - (w - 1)
-    a = stride(v, (restricted_length, w, d1), (s0, s0, s1))
-    rolled_df = pd.concat({
-        row: pd.DataFrame(values, columns=df.columns)
-        for row, values in zip(df.index[-restricted_length:], a)
-    })
-    return rolled_df.groupby(level=0)
-
 
 
 class AbstractRunner(ABC):
@@ -88,7 +63,7 @@ class SimpleSignalRunner(AbstractRunner):
             skipping_size = lookback_window
             # kwargs = {**generics, **idios}
             signal_generation_method_to_call = getattr(signal_generator, signal_type)
-            hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
+            hourly_df = signal_utility.roll_wrapper(hourly_df, lookback_window, skipping_size,
                                       lambda x: signal_generation_method_to_call(data=x, **idios), trigger)
         hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs , normalization = normalization)
         sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
