@@ -1,9 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
-import pandas as pd
-from napoleontoolbox.utility import metrics
+
 from numpy.lib.stride_tricks import as_strided as stride
+import pandas as pd
+from scipy.optimize import Bounds, LinearConstraint, minimize
+from napoleontoolbox.utility import metrics
 import numpy as np
+from napoleontoolbox.signal import signal_utility
+
 
 def convert_to_sql_column_format(run):
     run = run.replace('[', 'ccg')
@@ -101,4 +105,63 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     return data
 
 def compute_turn_over(data=None):
-    return abs((data.signal - data.signal.shift(-1).fillna(0.))).mean()
\ No newline at end of file
+    return abs((data.signal - data.signal.shift(-1).fillna(0.))).mean()
+
+
+def optimize_weights(data = None, starting_date = None, ending_date = None):
+    #T = data.index.size
+    print(max(data.index))
+    print(min(data.index))
+    data = data[data.index >= starting_date]
+    data = data[data.index <= ending_date]
+    print(max(data.index))
+    print(min(data.index))
+    all_sigs = [col for col in data.columns if 'signal' in col]
+    N_ = len(all_sigs)
+    w0 = np.ones([N_]) / N_
+
+    const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
+    up_bound = 1.
+    low_bound = 0.
+    up_bound_ = max(up_bound, 1 / N_)
+    low_bound_ = min(low_bound, 1 / N_)
+    const_ind = Bounds(low_bound_ * np.ones([N_]), up_bound_ * np.ones([N_]))
+    to_optimize = lambda x : signal_utility.f_sharpe_signals_mix(data, x)
+    w__ = minimize(
+        to_optimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    ).x
+    print('optimal weights')
+    print(w__)
+    return w__
+
+def compute_signals_weights_perf(data = None, optimal_weights = None, starting_date = None, ending_date = None, normalization = False):
+    print(max(data.index))
+    print(min(data.index))
+    data = data[data.index >= starting_date]
+    data = data[data.index <= ending_date]
+    print(max(data.index))
+    print(min(data.index))
+    all_sigs = [col for col in data.columns if 'signal' in col]
+    temp_df = data[['close', 'signal0']].copy()
+    temp_df = temp_df.rename(columns={"signal0": "signal"}, errors="raise")
+    optimal_signal = pd.DataFrame(data[all_sigs].values * optimal_weights, columns=all_sigs, index=data.index)
+    temp_df['signal'] = optimal_signal.sum(axis=1)
+    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=False, normalization=normalization)
+    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
+    print('underlying sharpe')
+    print(sharpe_under)
+    print('strat sharpe without transaction costs')
+    print(sharpe_strat)
+    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, normalization=normalization)
+    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
+    print('underlying sharpe')
+    print(sharpe_under)
+    print('strat sharpe with transaction costs')
+    print(sharpe_strat)
+    return sharpe_strat
\ No newline at end of file
